#!/usr/bin/python
# SPDX-FileCopyrightText: 2018 Mikey Sklar for Adafruit Industries
#
# SPDX-License-Identifier: MIT

# This script requires a Raspberry Pi 2, 3 or Zero. Circuit Python must
# be installed and it is strongly recommended that you use the latest
# release of Raspbian.
#
# This knitting clock daemon is based off of Adafruit motor hat and circuit
# python examples, to control a knitting machine.
# This script is licensed under GPLv3.

import time
import os
import board
import digitalio
from adafruit_motorkit import MotorKit
from adafruit_motor import stepper

kit = MotorKit(i2c=board.I2C())

button1 = digitalio.DigitalInOut(board.D19)
button1.direction = digitalio.Direction.INPUT
button1.pull = digitalio.Pull.UP

button2 = digitalio.DigitalInOut(board.D21)
button2.direction = digitalio.Direction.INPUT
button2.pull = digitalio.Pull.UP

while True:
    current_time = time.localtime()

    if (current_time.tm_min == 0): # knit every hour
      hour = int(time.strftime("%I"))
      # 1176 steps = full rotation, 98 steps = 1/12 rotation = one hour
      steps = 92
      for j in range(steps - (round(steps/hour) * hour)): # make up for any missed steps due to rounding
        kit.stepper1.onestep(style=stepper.DOUBLE,direction=stepper.FORWARD)
        time.sleep(.01)
        # steps split across number of hours
      for k in range(hour):
        # backtrack a bit to help clear up any jams
        for l in range(round(steps/10)):
          kit.stepper1.onestep(style=stepper.DOUBLE,direction=stepper.BACKWARD)
          time.sleep(.01)
        for l in range(round(steps/10)):
          kit.stepper1.onestep(style=stepper.DOUBLE,direction=stepper.FORWARD)
          time.sleep(.01)
        for i in range(round(steps/hour)):
          kit.stepper1.onestep(style=stepper.DOUBLE,direction=stepper.FORWARD)
          time.sleep(.01)
        kit.stepper1.release()
        time.sleep(0.2)
      time.sleep(61) # ensure we only hit this condition once every minute

# detect button presses
    if not button1.value:
         for i in range(54):
           kit.stepper1.onestep(style=stepper.DOUBLE,direction=stepper.BACKWARD)
           time.sleep(.01)

         kit.stepper1.release()

    elif not button2.value:
         for i in range(54):
           kit.stepper1.onestep(style=stepper.DOUBLE,direction=stepper.FORWARD)
           time.sleep(.01)

         kit.stepper1.release()

    else:
         time.sleep(.25)

